@@ -7,7 +7,7 @@ u"""
     ~~~~~~~~~~~~~~~~~~~~~~~
 
     キャッシュストア
-    
+
 ===============================
 """
 
@@ -23,8 +23,6 @@ from itertools import izip
 from time import time
 
 
-
-
 try:
     import cPickle as msg
 except ImportError, e:
@@ -41,12 +39,13 @@ u"""-----------------------------
     キャッシュストアの抽象クラス
 
 ------------------------------"""
+
+
 class BaseCacheStore(object):
 
     def __init__(self, default_timeout=300):
         self.default_timeout = default_timeout
 
-
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -60,8 +59,6 @@ class BaseCacheStore(object):
     def get(self, key):
         pass
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -75,8 +72,6 @@ class BaseCacheStore(object):
     def getMany(self, *keys):
         return map(self.get, keys)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -90,8 +85,6 @@ class BaseCacheStore(object):
     def getDict(self, *keys):
         return dict(izip(keys, self.getMany(*keys)))
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -105,8 +98,6 @@ class BaseCacheStore(object):
     def delete(self, key):
         pass
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -122,8 +113,6 @@ class BaseCacheStore(object):
     def set(self, key, value, timeout=None):
         pass
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -139,8 +128,6 @@ class BaseCacheStore(object):
     def add(self, key, value, timeout=None):
         pass
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -154,9 +141,7 @@ class BaseCacheStore(object):
     ------------------------------"""
     def setMany(self, mapping, timeout=None):
         for k, v in _items(mapping):
-            self.set(k, v,timeout)
-
-
+            self.set(k, v, timeout)
 
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
@@ -169,9 +154,7 @@ class BaseCacheStore(object):
 
     ------------------------------"""
     def deleteMany(self, *keys):
-        [ self.delete(k) for k in keys ]
-
-
+        [self.delete(k) for k in keys]
 
     u"""-----------------------------
         Shimehari.core.cachestore.BaseCacheStore
@@ -190,6 +173,7 @@ class BaseCacheStore(object):
 class NullCacheStore(BaseCacheStore):
     pass
 
+
 u"""-----------------------------
     Shimehari.core.cachestore.SimpleCacheStore
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -197,6 +181,8 @@ u"""-----------------------------
     メモリ上に突っ込むシンプルなキャッシュ
 
     ------------------------------"""
+
+
 class SimpleCacheStore(BaseCacheStore):
     def __init__(self, threshold=500, default_timeout=300):
         BaseCacheStore.__init__(self, default_timeout)
@@ -204,8 +190,6 @@ class SimpleCacheStore(BaseCacheStore):
         self.clear = self._cache.clear
         self._threshold = threshold
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore._prune
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -218,12 +202,10 @@ class SimpleCacheStore(BaseCacheStore):
         #キャッシュの数が増えた時消す
         if len(self._cache) > self._threshold:
             now = time()
-            for ind, (expires, _) in enumerate(self._cache.items()):
+            for ind, (key, (expires, _)) in enumerate(self._cache.items()):
                 if expires <= now or ind % 3 == 0:
                     self._cache.pop(key, None)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.SimpleCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -235,11 +217,9 @@ class SimpleCacheStore(BaseCacheStore):
     def get(self, key):
         now = time()
         expires, value = self._cache.get(key, (0, None))
-        if expires > time():
+        if expires > now:
             return msg.loads(value)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.SimpleCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -255,7 +235,6 @@ class SimpleCacheStore(BaseCacheStore):
         self._prune()
         self._cache[key] = (time() + timeout, msg.dumps(value, msg.HIGHEST_PROTOCOL))
 
-
     u"""-----------------------------
         Shimehari.core.cachestore.SimpleCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -273,8 +252,6 @@ class SimpleCacheStore(BaseCacheStore):
         item = (time() + timeout, msg.dumps(value, msg.HIGHEST_PROTOCOL))
         self._cache.setdefault(key, item)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.SimpleCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -289,17 +266,23 @@ class SimpleCacheStore(BaseCacheStore):
 
 import re
 from shimehari.core.helpers import importPreferredMemcachedClient
+
+
 u"""-----------------------------
     Shimehari.core.cachestore.MemcachedCacheStore
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    
+
     Memcache を使ったキャッシュストア
     ------------------------------"""
+
+
 _testMemcachedKey = re.compile(r'[^\x00-\x21\xff]{1,250}$').match
+
+
 class MemcachedCacheStore(BaseCacheStore):
     def __init__(self, servers=None, default_timeout=300, key_prefix=None):
         BaseCacheStore.__init__(self, default_timeout)
-        if servers is None or isinstance(servers, (list,tuple)):
+        if servers is None or isinstance(servers, (list, tuple)):
             if servers is None:
                 servers = ['127.0.0.1:11211']
             self._client = importPreferredMemcachedClient(servers)
@@ -310,8 +293,6 @@ class MemcachedCacheStore(BaseCacheStore):
 
         self.key_prefix = key_prefix
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -325,7 +306,7 @@ class MemcachedCacheStore(BaseCacheStore):
 
     ------------------------------"""
     def get(self, key):
-        if isinstance(key,unicode):
+        if isinstance(key, unicode):
             key = key.encode('utf-8')
         if self.key_prefix:
             key = self.key_prefix + key
@@ -333,8 +314,6 @@ class MemcachedCacheStore(BaseCacheStore):
         if _testMemcachedKey(key):
             return self._client.get(key)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -371,8 +350,6 @@ class MemcachedCacheStore(BaseCacheStore):
                     rv[k] = None
         return rv
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -383,9 +360,7 @@ class MemcachedCacheStore(BaseCacheStore):
     ------------------------------"""
     def getMany(self, *keys):
         d = self.getDict(*keys)
-        return [d[k] for k in keys ]
-
-
+        return [d[k] for k in keys]
 
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
@@ -407,8 +382,6 @@ class MemcachedCacheStore(BaseCacheStore):
         if self.key_prefix:
             key = self.key_prefix + key
         self._client.set(key, value, timeout)
-        
-
 
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
@@ -430,8 +403,6 @@ class MemcachedCacheStore(BaseCacheStore):
             newMap[k] = v
         self._client.set_multi(newMap, timeout)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -449,8 +420,6 @@ class MemcachedCacheStore(BaseCacheStore):
             key = self.key_prefix + key
         self._client.add(key, value, timeout)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -469,8 +438,6 @@ class MemcachedCacheStore(BaseCacheStore):
         if _testMemcachedKey(key):
             self._client.delete(key)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.MemcachedCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -494,7 +461,6 @@ class MemcachedCacheStore(BaseCacheStore):
         self._client.flush_all()
 
 
-
 u"""-----------------------------
     Shimehari.core.cachestore.FileSystemCacheStore
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -502,7 +468,11 @@ u"""-----------------------------
     FileSystem を使ったキャッシュストア
 
 ------------------------------"""
-_fsTransactionSuffix ='.__sakekasu'
+
+
+_fsTransactionSuffix = '.__sakekasu'
+
+
 class FileSystemCacheStore(BaseCacheStore):
     def __init__(self, cacheDir, threshold=500, default_timeout=300, mode=0600):
         BaseCacheStore.__init__(self, default_timeout)
@@ -513,7 +483,6 @@ class FileSystemCacheStore(BaseCacheStore):
         if not os.path.exists(self._cacheDir):
             os.makedirs(self._cacheDir)
 
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -525,8 +494,6 @@ class FileSystemCacheStore(BaseCacheStore):
     def _getFileList(self):
         return [os.path.join(self._cacheDir, fn) for fn in os.listdir(self._cacheDir) if not fn.endswith(_fsTransactionSuffix)]
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -539,8 +506,6 @@ class FileSystemCacheStore(BaseCacheStore):
         hash = md5(key).hexdigest()
         return os.path.join(self._cacheDir, hash)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -575,8 +540,6 @@ class FileSystemCacheStore(BaseCacheStore):
                     except (IOError, OSError):
                         pass
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -602,8 +565,6 @@ class FileSystemCacheStore(BaseCacheStore):
         except Exception:
             return None
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -634,8 +595,6 @@ class FileSystemCacheStore(BaseCacheStore):
         except (IOError, OSError), e:
             pass
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -653,8 +612,6 @@ class FileSystemCacheStore(BaseCacheStore):
         if not os.path.exists(fn):
             self.set(key, value, timeout)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -671,8 +628,6 @@ class FileSystemCacheStore(BaseCacheStore):
         except (IOError, OSError):
             pass
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.FileSystemCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -689,13 +644,14 @@ class FileSystemCacheStore(BaseCacheStore):
                 pass
 
 
-
 u"""-----------------------------
     Shimehari.core.cachestore.RedisCacheStore
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     Redis を使ったキャッシュストア
 
 ------------------------------"""
+
+
 class RedisCacheStore(BaseCacheStore):
     def __init__(self, host='localhost', port=6379, passwd=None, default_timeout=300, key_prefix=None):
         BaseCacheStore.__init__(self, default_timeout)
@@ -709,14 +665,12 @@ class RedisCacheStore(BaseCacheStore):
             self._client = host
         self.key_prefix = key_prefix or ''
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
         dump
 
-        与えられた値をシリアライズします。  
+        与えられた値をシリアライズします。
         [args]
             :value  シリアライズしたい値
 
@@ -728,8 +682,6 @@ class RedisCacheStore(BaseCacheStore):
         else:
             return '!' + msg.dumps(value)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -750,7 +702,6 @@ class RedisCacheStore(BaseCacheStore):
         except ValueError:
             return value
 
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -767,8 +718,6 @@ class RedisCacheStore(BaseCacheStore):
     def get(self, key):
         return self.load(self._client.get(self.key_prefix + key))
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -786,8 +735,6 @@ class RedisCacheStore(BaseCacheStore):
             keys = [self.key_prefix + k for k in keys]
         return [self.load(x) for x in self._client.mget(keys)]
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -806,8 +753,6 @@ class RedisCacheStore(BaseCacheStore):
         dump = self.dump(value)
         self._client.setex(self.key_prefix + key, dump, timeout)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -824,12 +769,10 @@ class RedisCacheStore(BaseCacheStore):
             timeout = self.default_timeout
         pipe = self._client.pipeline()
         for k, v in _items(mapping):
-            dump = self.dump(v)
+            self.dump(v)
             pipe.setex(self.key_prefix + k, v, timeout)
         pipe.execute()
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -843,13 +786,11 @@ class RedisCacheStore(BaseCacheStore):
     def add(self, key, value, timeout=None):
         if timeout is None:
             timeout = self.default_timeout
-        dump = self.dump(value)
+        self.dump(value)
         added = self._client.setnx(self.key_prefix + key, value)
         if added:
             self._client.expire(self.key_prefix + key, timeout)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -863,8 +804,6 @@ class RedisCacheStore(BaseCacheStore):
     def delete(self, key):
         self._client.delete(self.key_prefix + key)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -882,8 +821,6 @@ class RedisCacheStore(BaseCacheStore):
             keys = [self.key_prefix + k for k in keys]
         self._client.delete(*keys)
 
-
-
     u"""-----------------------------
         Shimehari.core.cachestore.RedisCacheStore
         ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -898,4 +835,3 @@ class RedisCacheStore(BaseCacheStore):
             if keys:
                 self._client.delete(*keys)
         self._client.flushdb()
-
